.. _installation:

Installation
============

*species* can be installed from the |pypi| with the |pip|::

    $ pip install species

Alternatively, the repository can be cloned from |github|::

    $ git clone git@github.com:tomasstolker/species.git

In that case, the dependencies can be installed from the *species* folder::

    $ pip install -r requirements.txt

The installation can be tested by starting Python in interactive mode and printing the *species* version::

    >>> import species
    >>> print species.__version__

.. |pypi| raw:: html

   <a href="https://pypi.org/project/species/" target="_blank">PyPI repository</a>

.. |github| raw:: html

   <a href="https://github.com/tomasstolker/species" target="_blank">Github</a>

.. |pip| raw:: html

   <a href="https://packaging.python.org/tutorials/installing-packages/" target="_blank">pip package manager</a>
